  .inesprg $10   ; 16x 16KB PRG code
  .ineschr $10   ; 16x  8KB CHR data
  .inesmap $01   ; mapper 1 = MMC1, 4KB CHR bank swapping
  .inesmir 0   ; background mirroring
  
 
;;;;;;;;;;;;
    
  .bank 0
  .org $8000 

;;;;;;;;;;


RESET:
  SEI          ; disable IRQs
  CLD          ; disable decimal mode
  LDX #$40
  STX $4017    ; disable APU frame IRQ
  LDX #$FF
  TXS          ; Set up stack
  INX          ; now X = 0
  STX $2000    ; disable NMI
  STX $2001    ; disable rendering
  STX $4010    ; disable DMC IRQs

vblankwait1:       ; First wait for vblank to make sure PPU is ready
  BIT $2002
  BPL vblankwait1
 
clrmem:
  LDA #$00
  STA $0000, x
  STA $0100, x
  STA $0300, x
  STA $0400, x
  STA $0500, x
  STA $0600, x
  STA $0700, x
  LDA #$FE
  STA $0200, x
  INX
  BNE clrmem

  LDX #%00011000
  jsr initMMC1Mapper
   
vblankwait2:      ; Second wait for vblank, PPU is ready after this
  BIT $2002
  BPL vblankwait2
 
 
LoadPalettes:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$3F
  STA $2006             ; write the high byte of $3F00 address
  LDA #$00
  STA $2006             ; write the low byte of $3F00 address
  LDX #$00              ; start out at 0
LoadPalettesLoop:
  LDA palette, x        ; load data from address (palette + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$20              ; Compare X to hex $20, decimal 32 - copying 32 bytes = 8 pallets
  BNE LoadPalettesLoop  ; Branch to LoadPalettesLoop if compare was Not Equal to zero
                        ; if compare was equal to 32, keep going down


LoadSprites:
  LDX #$00              ; start at 0
LoadSpritesLoop:
  LDA sprites, x        ; load data from address (sprites +  x)
  STA $0200, x          ; store into RAM address ($0200 + x)
  INX                   ; X = X + 1
  CPX #$10             ; Compare X to hex $10, decimal 16
  BNE LoadSpritesLoop   ; Branch to LoadSpritesLoop if compare was Not Equal to zero
                        ; if compare was equal to 20, keep going down


LoadAttribute:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$23
  STA $2006             ; write the high byte of $23C0 address
  LDA #$C0
  STA $2006             ; write the low byte of $23C0 address
  LDX #$00              ; start out at 00
LoadAttributeLoop:
  LDA Attribute, x      ; load data from address (attribute + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$40              ; Compare X to hex $10, decimal 16 - copying 16 bytes
  BNE LoadAttributeLoop  ; Branch to LoadAttributeLoop if compare was Not Equal to zero
                        ; if compare was equal to 16, keep going down
 

  JSR LoadBackground


Forever:
  JMP Forever     ;jump back to Forever, infinite loop
  
 
 
NMI:

  LDA #$00
  STA $2003       ; set the low byte (00) of the RAM address
  LDA #$02
  STA $4014       ; set the high byte (02) of the RAM address, start the transfer

LatchController:
  LDA #$01
  STA $4016
  LDA #$00
  STA $4016       ; tell both the controllers to latch buttons


ReadA: 
  LDA $4016       ; player 1 - A
  AND #%00000001  ; only look at bit 0
  BEQ ReadADone   ; branch to ReadADone if button is NOT pressed (0)
  LDA #$08
  JSR setCHRPage0000
  JMP ReadRightDone
ReadADone:        ; handling this button is done
  
 
ReadB: 
  LDA $4016       ; player 1 - B
  AND #%00000001  ; only look at bit 0
  BEQ ReadBDone
  LDA #$1E
  JSR setCHRPage0000
  JMP ReadRightDone
ReadBDone:        ; handling this button is done
 
 
ReadSelect: 
  LDA $4016       ; player 1 - select
  ;AND #%00000001  ; only look at bit 0
  ;BEQ ReadSelectDone   ; branch to ReadSelectDone if button is NOT pressed (0)
                  ; add instructions here to do something when button IS pressed (1)
ReadSelectDone:   ; handling this button is done
 
 
ReadStart: 
  LDA $4016       ; player 1 - start
  ;AND #%00000001  ; only look at bit 0
  ;BEQ ReadStartDone   ; branch to ReadStartDone if button is NOT pressed (0)
                  ; add instructions here to do something when button IS pressed (1)
 ReadStartDone:   ; handling this button is done

ReadUp:
  LDA $4016	;Up
  AND #%00000001
  BEQ ReadUpDone
  LDA #$03
  JSR setPRGBank
  JSR LoadBackground
  JMP ReadRightDone
ReadUpDone:

;;;

ReadDown:
  LDA $4016	;Down
  AND #%00000001
  BEQ ReadDownDone
  LDA #$0D
  JSR setPRGBank
  JSR LoadBackgrounds
  JMP ReadRightDone
ReadDownDone:

;;;

ReadLeft:
  LDA $4016	;Left
  AND #%00000001
  BEQ ReadLeftDone
  LDA #$09
  JSR setCHRPage1000
  JMP ReadRightDone
ReadLeftDone:

;;;

ReadRight:
  LDA $4016	;Right
  AND #%00000001
  BEQ ReadRightDone
  LDA #$1B
  JSR setCHRPage1000
ReadRightDone:
  
  RTI             ; return from interrupt
 
 
;;;;;;;;;;;;;;;;;;;;;;
 
initMMC1Mapper:
  LDA #$80
  STA $8000
 
  TXA
  JSR setMMC1ControlMode
 
  LDA #$02
  JSR setCHRPage0000

  LDA #$01
  JSR setCHRPage1000
 
 
  LDA #$03
  JSR setPRGBank
 
  RTS
 
setMMC1ControlMode:
        STA $8000 
        LSR A 
        STA $8000 
        LSR A 
        STA $8000 
        LSR A 
        STA $8000 
        LSR A 
        STA $8000 
  RTS
 
setCHRPage0000:
        STA $A000
        LSR A
        STA $A000
        LSR A
        STA $A000
        LSR A
        STA $A000
        LSR A
        STA $A000  
  RTS

setCHRPage1000:
        STA $C000
        LSR A
        STA $C000
        LSR A
        STA $C000
        LSR A
        STA $C000
        LSR A
        STA $C000 
  RTS 
 
setPRGBank:
        STA $E000 
        LSR A 
        STA $E000 
        LSR A 
        STA $E000 
        LSR A 
        STA $E000 
        LSR A 
        STA $E000 
  RTS
 
 
;;;;;;;;;;;;;;  
  
  .bank 1
  .org $A000

;;;;;;;;;;;;;;

palette:

  .db $0F,$21,$12,$02, $0F,$21,$12,$02, $0F,$21,$12,$02, $0F,$21,$12,$02
  .db $0F,$08,$28,$06, $0F,$08,$28,$06, $0F,$08,$28,$06, $0F,$08,$28,$06

sprites:
     ;vert tile attr horiz
  .db $80, $00, $00, $80   ;Nightman 1
  .db $80, $01, $00, $88   ;Nightman 2
  .db $88, $10, $00, $80   ;Nightman 3
  .db $88, $11, $00, $88   ;Nightman 4

Attribute:

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

  .db %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000, %00000000

;;;;------------

LoadBackground:

  LDA #%00010000   ; disable NMI, sprites from Pattern Table 0, background from Pattern Table 1
  STA $2000

  LDA #%00000110   ; disable sprites, disable background, no clipping on left side
  STA $2001


  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$20
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackgrounda0:
  LDA Background0, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$00              ; Compare X to hex $00, decimal 256 - copying 256 bytes
  BNE LoadBackgrounda0  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

LoadBackgrounda:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$21
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackground1:
  LDA Background1, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$00              ; Compare X to hex $00, decimal 256 - copying 256 bytes
  BNE LoadBackground1  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

LoadBackgroundb:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$22
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackground2:
  LDA Background2, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$00              ; Compare X to hex $00, decimal 256 - copying 256 bytes
  BNE LoadBackground2  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

LoadBackgroundc:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$23
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackground3:
  LDA Background3, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$C0              ; Compare X to hex $C0, decimal 192 - copying 192 bytes
  BNE LoadBackground3  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

vblankwait3:
  BIT $2002
  BPL vblankwait3


  LDA #%00011110   ; enable sprites, enable background, no clipping on left side
  STA $2001


  LDA #%10010000   ; enable NMI, sprites from Pattern Table 0, background from Pattern Table 1
  STA $2000


  LDA #$00        ;;tell the ppu there is no background scrolling
  STA $2005
  STA $2005

  RTS

;;;;;;;;;;;;;;----------

LoadBackgrounds:

  LDA #%00010000   ; disable NMI, sprites from Pattern Table 0, background from Pattern Table 1
  STA $2000

  LDA #%00000110   ; disable sprites, disable background, no clipping on left side
  STA $2001


  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$20
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackgroundsa0:
  LDA Backgrounds0, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$00              ; Compare X to hex $00, decimal 256 - copying 256 bytes
  BNE LoadBackgroundsa0  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

LoadBackgroundsa:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$21
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackgrounds1:
  LDA Backgrounds1, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$00              ; Compare X to hex $00, decimal 256 - copying 256 bytes
  BNE LoadBackgrounds1  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

LoadBackgroundsb:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$22
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackgrounds2:
  LDA Backgrounds2, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$00              ; Compare X to hex $00, decimal 256 - copying 256 bytes
  BNE LoadBackgrounds2  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

LoadBackgroundsc:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$23
  STA $2006             ; write the high byte of $2000 address
  LDA #$00
  STA $2006             ; write the low byte of $2000 address
  LDX #$00              ; start out at 0
LoadBackgrounds3:
  LDA Backgrounds3, x     ; load data from address (background + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$C0              ; Compare X to hex $C0, decimal 192 - copying 192 bytes
  BNE LoadBackgrounds3  ; Branch to LoadBackgroundLoop if compare was Not Equal to zero
                        ; if compare was equal to 256, keep going down

vblankwait4:
  BIT $2002
  BPL vblankwait4


  LDA #%00011110   ; enable sprites, enable background, no clipping on left side
  STA $2001


  LDA #%10010000   ; enable NMI, sprites from Pattern Table 0, background from Pattern Table 1
  STA $2000


  LDA #$00        ;;tell the ppu there is no background scrolling
  STA $2005
  STA $2005

  RTS



;;;;;;;;;;;;;;;;;;;
 
  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial
  

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 2
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 3
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 4
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 5
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 6
  .org $C000

;;;;;;;;;;;;

Background0:
  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 1

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 2

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 3

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 4

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 5

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 6

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 7

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 8

Background1:
  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 1

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 2

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 3

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 4

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 5

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 6

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 7

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 8

Background2:
  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 1

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 2

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 3

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 4

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 5

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 6

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 7

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 8

Background3:
  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 1

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 2

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 3

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 4

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 5

  .db $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11, $02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11,$02,$10,$11,$11  ;;row 6

;;;;;;;;;;;;

  .bank 7
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 8
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 9
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 10
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 11
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 12
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 13
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 14
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 15
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 16
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 17
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 18
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 19
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 20
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 21
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 22
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 23
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 24
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 25
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 26
  .org $C000

;;;;;;;;;;;;

Backgrounds0:
  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 1

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 2

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 3

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 4

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 5

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 6

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 7

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 8

Backgrounds1:
  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 1

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 2

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 3

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 4

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 5

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 6

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 7

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 8

Backgrounds2:
  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 1

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 2

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 3

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 4

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 5

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 6

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 7

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 8

Backgrounds3:
  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 1

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 2

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 3

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 4

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 5

  .db $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01, $00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01,$00,$02,$01,$01  ;;row 6

;;;;;;;;;;;;

  .bank 27
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 28
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 29
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial

;;;;;;;;;;;;
;;;;;;;;;;;;
  
  .bank 30
  .org $C000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .bank 31
  .org $E000

;;;;;;;;;;;;
;;;;;;;;;;;;

  .org $FFFA     ;first of the three vectors starts here
  .dw NMI        ;when an NMI happens (once per frame if enabled) the 
                   ;processor will jump to the label NMI:
  .dw RESET      ;when the processor first turns on or is reset, it will jump
                   ;to the label RESET:
  .dw 0          ;external interrupt IRQ is not used in this tutorial


;;;;;;;;;;;;
;;;;;;;;;;;;
  
  
  .bank 32
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 34
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 36
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 38
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 40
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 42
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 44
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

  .bank 46
  .org $0000
  .incbin "MMC1.chr"   ;includes 16KB graphics file 

